NXSDataWriter Tango Class Properties

NXSDataWriter Properties :
There is no class properties

Device Properties
Name | Description | Type | Default Value
NumberOfThreads | maximal number of threads | int | 100
Writer | writer module: `pni` or `h5py` or `h5cpp` | String | none
MetadataOutput | metadata output: `file` | String | none
DefaultCanFail | Default value of CanFail attribute | boolean | True
AddingLogs | Add XML logs in nexus_logs of NXscollection | boolean | True
MaxRecordRuntime | maximal runtime for a record command in seconds | double | 0.0
MaxElementRuntime | maximal runtime for a thread element in seconds | double | 0.0